@@ -1,7 +1,7 @@
 import contextlib
 import dataclasses
 import urllib.parse
-from typing import Any, ContextManager, Type
+from typing import Any
 
 import psycopg
 import pymysql
@@ -87,13 +87,13 @@ class ConnectionMaker(object):
     def make_connection(self):
         return self.engine.connect()
 
-    def make_session(self, **kwargs) -> ContextManager[sqlalchemy.orm.Session]:
+    def make_session(self, **kwargs) -> contextlib.AbstractContextManager[sqlalchemy.orm.Session]:
         return contextlib.closing(sqlalchemy.orm.sessionmaker(self.engine, **{**self.session_opts, **kwargs})())
 
-    def create_model(self, orm_base: Type[sqlalchemy.orm.DeclarativeBase]):
+    def create_model(self, orm_base: type[sqlalchemy.orm.DeclarativeBase]):
         orm_base.metadata.create_all(self.engine)
 
-    def drop_model(self, orm_base: Type[sqlalchemy.orm.DeclarativeBase]):
+    def drop_model(self, orm_base: type[sqlalchemy.orm.DeclarativeBase]):
         orm_base.metadata.drop_all(self.engine)
 
     def execute(self, sql: str, **params):
