@@ -3,9 +3,12 @@ import math
 import random
 import string
 import sys
+from collections.abc import Callable, Sequence
+from typing import TypeVar
 
 from iker.common.utils.dtutils import dt_utc_max, dt_utc_min
 from iker.common.utils.funcutils import memorized, singleton
+from iker.common.utils.sequtils import head_or_none
 
 __all__ = [
     "max_int",
@@ -14,6 +17,8 @@ __all__ = [
     "randomizer",
 ]
 
+T = TypeVar("T")
+
 
 @singleton
 def max_int() -> int:
@@ -142,6 +147,21 @@ class Randomizer(object):
 
         return generate_json_object(0)
 
+    def sample(self, population: Sequence[T], count_func: Callable[[T], int] = None, k: int = None) -> list[T] | T:
+        counts = list(map(count_func, population)) if callable(count_func) else None
+        result = self.random.sample(population, counts=counts, k=k or 1)
+        return result if k is not None else head_or_none(result)
+
+    def choose(self, population: Sequence[T], weight_func: Callable[[T], float] = None, k: int = None) -> list[T] | T:
+        weights = list(map(weight_func, population)) if callable(weight_func) else None
+        result = self.random.choices(population, weights=weights, k=k or 1)
+        return result if k is not None else head_or_none(result)
+
+    def shuffle(self, data: Sequence[T]) -> list[T]:
+        clone = list(item for item in data)
+        self.random.shuffle(clone)
+        return clone
+
 
 @memorized
 def randomizer(seed: int = 0) -> Randomizer:
