@@ -1,5 +1,3 @@
-from __future__ import annotations
-
 import functools
 import itertools
 from collections.abc import Callable, Generator, Iterable, Iterator, Sequence, Sized
@@ -371,10 +369,10 @@ class Seq(Generic[Tco], Sequence[Tco], Sized):
     def intersect(self, other: Self) -> Self:
         return Seq(list(set(self.data).intersection(set(other.data))))
 
-    def zip(self, other: Seq[U]) -> Seq[tuple[Tco, U]]:
+    def zip(self, other: "Seq[U]") -> "Seq[tuple[Tco, U]]":
         return Seq(zip(self.data, other.data))
 
-    def zip_fill(self, other: Seq[U], fill: Tco | U | None = None) -> Seq[tuple[Tco, U]]:
+    def zip_fill(self, other: "Seq[U]", fill: Tco | U | None = None) -> "Seq[tuple[Tco, U]]":
         return Seq(itertools.zip_longest(self.data, other.data, fillvalue=fill))
 
 
