@@ -1,8 +1,8 @@
 import datetime
+from collections.abc import Callable
 from typing import Any
 
 from iker.common.utils.dtutils import dt_parse_iso
-from iker.common.utils.sequtils import head, last
 
 __all__ = [
     "is_none",
@@ -18,6 +18,7 @@ __all__ = [
     "str_conv",
     "repr_data",
     "parse_params_string",
+    "make_params_string",
     "strip_margin",
 ]
 
@@ -125,23 +126,61 @@ def repr_data(o) -> str:
     return str(o)
 
 
-def parse_params_string(s: str, delimiter: str = ",", kv_delimiter: str = "=") -> dict[str, str]:
+def parse_params_string(
+    s: str,
+    *,
+    delim: str = ",",
+    kv_delim: str = "=",
+    neg_prefix: str = "-",
+    str_parser: Callable[[str], Any] = str,
+    true_value: Any = True,
+    false_value: Any = False,
+) -> dict[str, Any]:
     if is_blank(s):
         return {}
 
     result = {}
-    for param in s.split(delimiter):
-        segments = param.split(kv_delimiter, 1)
-        if len(segments) == 1:
-            result[head(segments)] = str(True)
-        elif len(segments) == 2:
-            result[head(segments)] = last(segments)
-        else:
-            raise ValueError("malformed param <%s>" % param)
+    for param in s.split(delim):
+        match param.split(kv_delim, 1):
+            case [key]:
+                if len(key) == 0 or key == neg_prefix:
+                    continue
+                if key.startswith(neg_prefix):
+                    result[key[len(neg_prefix):]] = false_value
+                else:
+                    result[key] = true_value
+            case [key, value]:
+                if len(key) == 0 or key == neg_prefix:
+                    continue
+                result[key] = str_parser(value)
+            case _:
+                raise ValueError("malformed param <%s>" % param)
     return result
 
 
-def strip_margin(text: str, margin_char: str = "|") -> str:
+def make_params_string(
+    params: dict[str, Any],
+    *,
+    delim: str = ",",
+    kv_delim: str = "=",
+    neg_prefix: str = "-",
+    str_maker: Callable[[Any], str] = str,
+) -> str:
+    if len(params or {}) == 0:
+        return ""
+
+    kv_strs = []
+    for key, value in params.items():
+        if len(key) == 0 or key == neg_prefix:
+            continue
+        if isinstance(value, bool):
+            kv_strs.append(key if value is True else neg_prefix + key)
+        else:
+            kv_strs.append(kv_delim.join((key, str_maker(value))))
+    return delim.join(kv_strs)
+
+
+def strip_margin(text: str, *, margin_char: str = "|", line_concat: str = " ") -> str:
     stripped_text = ""
     last_stripped_line = ""
     for lineno, line in enumerate(text.splitlines()):
@@ -152,7 +191,7 @@ def strip_margin(text: str, margin_char: str = "|") -> str:
             if lineno > 0:
                 stripped_text += "\n"
         elif len(last_stripped_line) > 0:
-            stripped_text += " " + stripped_line
+            stripped_text += line_concat + stripped_line
         else:
             stripped_text += stripped_line
         last_stripped_line = stripped_line
