@@ -12,7 +12,7 @@ from sqlalchemy.exc import IntegrityError
 from sqlalchemy.orm import DeclarativeBase, Mapped, MappedAsDataclass
 from sqlalchemy.orm.exc import FlushError
 
-from iker.common.utils.dbutils import DBAdapter
+from iker.common.utils.dbutils import ConnectionMaker
 from iker.common.utils.dbutils import mysql_insert_ignore, postgresql_insert_on_conflict_do_nothing
 from iker.common.utils.dbutils import orm_clone
 from iker.common.utils.funcutils import unique_returns
@@ -107,18 +107,18 @@ class PostgresqlDummyRecord(PostgresqlBaseModel):
 
 
 @pytest.mark.skipif(sys.platform == "win32", reason="Test not applicable on Windows")
-def test_mysql_adapter(fixture_mysql_test_proc, fixture_mysql_test):
-    adapter = DBAdapter(DBAdapter.Drivers.Mysql,
-                        "127.0.0.1",
-                        fixture_mysql_test_proc.port,
-                        fixture_mysql_test_proc.user,
-                        None,
-                        "test",
-                        session_opts=dict(
-                            expire_on_commit=False,
-                        ))
+def test_mysql_connection_maker(fixture_mysql_test_proc, fixture_mysql_test):
+    maker = ConnectionMaker(ConnectionMaker.Drivers.Mysql,
+                            "127.0.0.1",
+                            fixture_mysql_test_proc.port,
+                            fixture_mysql_test_proc.user,
+                            None,
+                            "test",
+                            session_opts=dict(
+                                expire_on_commit=False,
+                            ))
 
-    adapter.create_model(MysqlBaseModel)
+    maker.create_model(MysqlBaseModel)
 
     rng = randomizer()
 
@@ -144,28 +144,28 @@ def test_mysql_adapter(fixture_mysql_test_proc, fixture_mysql_test):
             dummy_unique_string=dummy_unique_string(),
         )
 
-    with adapter.make_session() as session:
+    with maker.make_session() as session:
         original_records = [random_record() for _ in range(0, 1000)]
         session.bulk_save_objects(original_records, return_defaults=True)
         session.commit()
 
-    with adapter.make_session() as session:
+    with maker.make_session() as session:
         count = session.query(sqlalchemy.func.count()).select_from(MysqlDummyRecord).scalar()
 
     assert count == 1000
 
-    with adapter.make_session() as session:
+    with maker.make_session() as session:
         delete_rows = session.query(MysqlDummyRecord).order_by(MysqlDummyRecord.dummy_id).offset(500).all()
         for delete_row in delete_rows:
             session.delete(delete_row)
         session.commit()
 
-    with adapter.make_session() as session:
+    with maker.make_session() as session:
         count = session.query(sqlalchemy.func.count()).select_from(MysqlDummyRecord).scalar()
 
     assert count == 500
 
-    with adapter.make_session() as session:
+    with maker.make_session() as session:
         records = session.query(MysqlDummyRecord).order_by(MysqlDummyRecord.dummy_id).all()
 
     for expect, actual in zip(original_records[:count], records[:count]):
@@ -189,12 +189,12 @@ def test_mysql_adapter(fixture_mysql_test_proc, fixture_mysql_test):
 
     mysql_insert_ignore()
 
-    with adapter.make_session() as session:
+    with maker.make_session() as session:
         # PK violation, but suppressed by the compiler plugin
         session.add(orm_clone(result))
         session.commit()
 
-    with adapter.make_session() as session:
+    with maker.make_session() as session:
         # Unique index violation, but suppressed by the plugin
         # Unlike the Postgresql implementation, MySQL will not raise a 'FlushError'.
         # Instead, it will fill the auto increment column with zero
@@ -203,34 +203,34 @@ def test_mysql_adapter(fixture_mysql_test_proc, fixture_mysql_test):
 
     mysql_insert_ignore(enabled=False)
 
-    with adapter.make_session() as session:
+    with maker.make_session() as session:
         # PK violation, which causes 'IntegrityError'
         with pytest.raises(IntegrityError):
             session.add(orm_clone(result))
             session.commit()
 
-    with adapter.make_session() as session:
+    with maker.make_session() as session:
         # Unique index violation, which causes 'IntegrityError'
         with pytest.raises(IntegrityError):
             session.add(orm_clone(result, no_autoincrement=True))
             session.commit()
 
-    adapter.drop_model(MysqlBaseModel)
+    maker.drop_model(MysqlBaseModel)
 
 
 @pytest.mark.skipif(sys.platform == "win32", reason="Test not applicable on Windows")
-def test_postgresql_adapter(fixture_postgresql_test_proc, fixture_postgresql_test):
-    adapter = DBAdapter(DBAdapter.Drivers.Postgresql,
-                        fixture_postgresql_test.info.host,
-                        fixture_postgresql_test.info.port,
-                        fixture_postgresql_test.info.user,
-                        None,
-                        fixture_postgresql_test.info.dbname,
-                        session_opts=dict(
-                            expire_on_commit=False,
-                        ))
+def test_postgresql_connection_maker(fixture_postgresql_test_proc, fixture_postgresql_test):
+    maker = ConnectionMaker(ConnectionMaker.Drivers.Postgresql,
+                            fixture_postgresql_test.info.host,
+                            fixture_postgresql_test.info.port,
+                            fixture_postgresql_test.info.user,
+                            None,
+                            fixture_postgresql_test.info.dbname,
+                            session_opts=dict(
+                                expire_on_commit=False,
+                            ))
 
-    adapter.create_model(PostgresqlBaseModel)
+    maker.create_model(PostgresqlBaseModel)
 
     rng = randomizer()
 
@@ -260,28 +260,28 @@ def test_postgresql_adapter(fixture_postgresql_test_proc, fixture_postgresql_tes
             dummy_unique_string=dummy_unique_string(),
         )
 
-    with adapter.make_session() as session:
+    with maker.make_session() as session:
         original_records = [random_record() for _ in range(0, 1000)]
         session.bulk_save_objects(original_records, return_defaults=True)
         session.commit()
 
-    with adapter.make_session() as session:
+    with maker.make_session() as session:
         count = session.query(sqlalchemy.func.count()).select_from(PostgresqlDummyRecord).scalar()
 
     assert count == 1000
 
-    with adapter.make_session() as session:
+    with maker.make_session() as session:
         delete_rows = session.query(PostgresqlDummyRecord).order_by(PostgresqlDummyRecord.dummy_id).offset(500).all()
         for delete_row in delete_rows:
             session.delete(delete_row)
         session.commit()
 
-    with adapter.make_session() as session:
+    with maker.make_session() as session:
         count = session.query(sqlalchemy.func.count()).select_from(PostgresqlDummyRecord).scalar()
 
     assert count == 500
 
-    with adapter.make_session() as session:
+    with maker.make_session() as session:
         records = session.query(PostgresqlDummyRecord).order_by(PostgresqlDummyRecord.dummy_id).all()
 
     for expect, actual in zip(original_records[:count], records[:count]):
@@ -309,12 +309,12 @@ def test_postgresql_adapter(fixture_postgresql_test_proc, fixture_postgresql_tes
 
     postgresql_insert_on_conflict_do_nothing()
 
-    with adapter.make_session() as session:
+    with maker.make_session() as session:
         # PK violation, but suppressed by the compiler plugin
         session.add(orm_clone(result))
         session.commit()
 
-    with adapter.make_session() as session:
+    with maker.make_session() as session:
         # Unique index violation, but suppressed by the plugin
         # However, since insertion is not performed, it fails to return and
         # flush the auto-generated primary key of the ORM, which raises 'FlushError'
@@ -324,16 +324,16 @@ def test_postgresql_adapter(fixture_postgresql_test_proc, fixture_postgresql_tes
 
     postgresql_insert_on_conflict_do_nothing(enabled=False)
 
-    with adapter.make_session() as session:
+    with maker.make_session() as session:
         # PK violation, which causes 'IntegrityError'
         with pytest.raises(IntegrityError):
             session.add(orm_clone(result))
             session.commit()
 
-    with adapter.make_session() as session:
+    with maker.make_session() as session:
         # Unique index violation, which causes 'IntegrityError'
         with pytest.raises(IntegrityError):
             session.add(orm_clone(result, no_autoincrement=True))
             session.commit()
 
-    adapter.drop_model(PostgresqlBaseModel)
+    maker.drop_model(PostgresqlBaseModel)
