@@ -8,7 +8,10 @@ from typing import SupportsFloat, SupportsInt
 import ddt
 import pytest
 
-from iker.common.utils.jsonutils import json_compare, json_reformat, json_sanitize, json_traverse
+from iker.common.utils.jsonutils import asterisk, json_get, json_set
+from iker.common.utils.jsonutils import json_compare
+from iker.common.utils.jsonutils import json_reformat, json_sanitize, json_traverse
+from iker.common.utils.randutils import randomizer
 
 
 @dataclass(eq=True, frozen=True)
@@ -66,6 +69,378 @@ class WrappedDict(Mapping):
 @ddt.ddt
 class JsonUtilsTest(unittest.TestCase):
 
+    @ddt.data(
+        (None, [], None),
+        (True, [], True),
+        (False, [], False),
+        (1, [], 1),
+        (-1, [], -1),
+        (0, [], 0),
+        (1.0, [], 1.0),
+        (-1.0, [], -1.0),
+        (0.0, [], 0.0),
+        (1.0e9, [], 1.0e9),
+        (-1.0e-9, [], -1.0e-9),
+        (math.nan, [], math.nan),
+        (math.inf, [], math.inf),
+        (-math.inf, [], -math.inf),
+        ("", [], ""),
+        ("dummy", [], "dummy"),
+        ([None, True, 1, 1.0, math.nan, math.inf, "dummy"], [0], None),
+        ([None, True, 1, 1.0, math.nan, math.inf, "dummy"], [1], True),
+        ([None, True, 1, 1.0, math.nan, math.inf, "dummy"], [2], 1),
+        ([None, True, 1, 1.0, math.nan, math.inf, "dummy"], [3], 1.0),
+        ([None, True, 1, 1.0, math.nan, math.inf, "dummy"], [4], math.nan),
+        ([None, True, 1, 1.0, math.nan, math.inf, "dummy"], [5], math.inf),
+        ([None, True, 1, 1.0, math.nan, math.inf, "dummy"], [6], "dummy"),
+        ([None, True, 1, 1.0, math.nan, math.inf, "dummy"], [7], None),
+        ([None, True, 1, 1.0, math.nan, math.inf, "dummy"], [-8], None),
+        ([None, True, 1, 1.0, math.nan, math.inf, "dummy"], [-7], None),
+        ([None, True, 1, 1.0, math.nan, math.inf, "dummy"], [-6], True),
+        ([None, True, 1, 1.0, math.nan, math.inf, "dummy"], [-5], 1),
+        ([None, True, 1, 1.0, math.nan, math.inf, "dummy"], [-4], 1.0),
+        ([None, True, 1, 1.0, math.nan, math.inf, "dummy"], [-3], math.nan),
+        ([None, True, 1, 1.0, math.nan, math.inf, "dummy"], [-2], math.inf),
+        ([None, True, 1, 1.0, math.nan, math.inf, "dummy"], [-1], "dummy"),
+        ([None, True, 1, 1.0, math.nan, math.inf, "dummy"], [], [None, True, 1, 1.0, math.nan, math.inf, "dummy"]),
+        ([None, True, 1, 1.0, math.nan, math.inf, "dummy"], [""], None),
+        (
+            {"none": None, "bool": True, "int": 1, "float": 1.0, "nan": math.nan, "inf": math.inf, "str": "dummy"},
+            ["none"],
+            None,
+        ),
+        (
+            {"none": None, "bool": True, "int": 1, "float": 1.0, "nan": math.nan, "inf": math.inf, "str": "dummy"},
+            ["bool"],
+            True,
+        ),
+        (
+            {"none": None, "bool": True, "int": 1, "float": 1.0, "nan": math.nan, "inf": math.inf, "str": "dummy"},
+            ["int"],
+            1,
+        ),
+        (
+            {"none": None, "bool": True, "int": 1, "float": 1.0, "nan": math.nan, "inf": math.inf, "str": "dummy"},
+            ["float"],
+            1.0,
+        ),
+        (
+            {"none": None, "bool": True, "int": 1, "float": 1.0, "nan": math.nan, "inf": math.inf, "str": "dummy"},
+            ["nan"],
+            math.nan,
+        ),
+        (
+            {"none": None, "bool": True, "int": 1, "float": 1.0, "nan": math.nan, "inf": math.inf, "str": "dummy"},
+            ["inf"],
+            math.inf,
+        ),
+        (
+            {"none": None, "bool": True, "int": 1, "float": 1.0, "nan": math.nan, "inf": math.inf, "str": "dummy"},
+            ["str"],
+            "dummy",
+        ),
+        (
+            {"none": None, "bool": True, "int": 1, "float": 1.0, "nan": math.nan, "inf": math.inf, "str": "dummy"},
+            [""],
+            None,
+        ),
+        (
+            {"none": None, "bool": True, "int": 1, "float": 1.0, "nan": math.nan, "inf": math.inf, "str": "dummy"},
+            [],
+            {"none": None, "bool": True, "int": 1, "float": 1.0, "nan": math.nan, "inf": math.inf, "str": "dummy"},
+        ),
+        (
+            {"none": None, "bool": True, "int": 1, "float": 1.0, "nan": math.nan, "inf": math.inf, "str": "dummy"},
+            [0],
+            None,
+        ),
+    )
+    @ddt.unpack
+    def test_json_get(self, data, node_path, expect):
+        self.assertTrue(json_compare(json_get(data, *node_path), expect))
+
+    @ddt.data(
+        (
+            {
+                "none": None,
+                "bool": {
+                    "bool_true": True,
+                    "bool_false": False,
+                },
+                "int": {
+                    "int_one": 1,
+                    "int_minus_one": -1,
+                    "int_zero": 0,
+                },
+                "float": {
+                    "float_one": 1.0,
+                    "float_minus_one": -1.0,
+                    "float_zero": 0.0,
+                    "float_one_e_nine": 1.0e9,
+                    "float_minus_one_e_minus_nine": -1.0e-9,
+                    "float_nan": math.nan,
+                    "float_inf": math.inf,
+                    "float_minus_inf": -math.inf,
+                },
+                "str": {
+                    "str_empty": "",
+                    "str": "dummy",
+                },
+                "list": [None, True, 1, 1.0, math.nan, math.inf, "dummy"],
+            },
+            [
+                (["none"], None),
+                (
+                    ["bool"],
+                    {
+                        "bool_true": True,
+                        "bool_false": False,
+                    },
+                ),
+                (["bool", "bool_true"], True),
+                (["bool", "bool_false"], False),
+                (["bool", ""], None),
+                (
+                    ["int"],
+                    {
+                        "int_one": 1,
+                        "int_minus_one": -1,
+                        "int_zero": 0,
+                    },
+                ),
+                (["int", "int_one"], 1),
+                (["int", "int_minus_one"], -1),
+                (["int", "int_zero"], 0),
+                (["int", ""], None),
+                (
+                    ["float"],
+                    {
+                        "float_one": 1.0,
+                        "float_minus_one": -1.0,
+                        "float_zero": 0.0,
+                        "float_one_e_nine": 1.0e9,
+                        "float_minus_one_e_minus_nine": -1.0e-9,
+                        "float_nan": math.nan,
+                        "float_inf": math.inf,
+                        "float_minus_inf": -math.inf,
+                    },
+                ),
+                (["float", "float_one"], 1.0),
+                (["float", "float_minus_one"], -1.0),
+                (["float", "float_zero"], 0.0),
+                (["float", "float_one_e_nine"], 1.0e9),
+                (["float", "float_minus_one_e_minus_nine"], -1.0e-9),
+                (["float", "float_nan"], math.nan),
+                (["float", "float_inf"], math.inf),
+                (["float", "float_minus_inf"], -math.inf),
+                (["float", ""], None),
+                (
+                    ["str"],
+                    {
+                        "str_empty": "",
+                        "str": "dummy",
+                    },
+                ),
+                (["str", "str_empty"], ""),
+                (["str", "str"], "dummy"),
+                (["str", ""], None),
+                (["list"], [None, True, 1, 1.0, math.nan, math.inf, "dummy"]),
+                (["list", 0], None),
+                (["list", 1], True),
+                (["list", 2], 1),
+                (["list", 3], 1.0),
+                (["list", 4], math.nan),
+                (["list", 5], math.inf),
+                (["list", 6], "dummy"),
+                (["list", 7], None),
+                (["list", -8], None),
+                (["list", -7], None),
+                (["list", -6], True),
+                (["list", -5], 1),
+                (["list", -4], 1.0),
+                (["list", -3], math.nan),
+                (["list", -2], math.inf),
+                (["list", -1], "dummy"),
+                ([""], None),
+                (["", 0], None),
+                ([0, ""], None),
+                (
+                    [],
+                    {
+                        "none": None,
+                        "bool": {
+                            "bool_true": True,
+                            "bool_false": False,
+                        },
+                        "int": {
+                            "int_one": 1,
+                            "int_minus_one": -1,
+                            "int_zero": 0,
+                        },
+                        "float": {
+                            "float_one": 1.0,
+                            "float_minus_one": -1.0,
+                            "float_zero": 0.0,
+                            "float_one_e_nine": 1.0e9,
+                            "float_minus_one_e_minus_nine": -1.0e-9,
+                            "float_nan": math.nan,
+                            "float_inf": math.inf,
+                            "float_minus_inf": -math.inf,
+                        },
+                        "str": {
+                            "str_empty": "",
+                            "str": "dummy",
+                        },
+                        "list": [None, True, 1, 1.0, math.nan, math.inf, "dummy"],
+                    },
+                ),
+            ],
+        )
+    )
+    @ddt.unpack
+    def test_json_get__comprehensive(self, data, queries):
+        for node_path, expect in queries:
+            self.assertTrue(json_compare(json_get(data, *node_path), expect))
+
+    def test_json_set(self):
+        queries = [
+            (["none"], None),
+            (
+                ["bool"],
+                {
+                    "bool_true": True,
+                    "bool_false": False,
+                },
+            ),
+            (["bool", "bool_true"], True),
+            (["bool", "bool_false"], False),
+            (
+                ["int"],
+                {
+                    "int_one": 1,
+                    "int_minus_one": -1,
+                    "int_zero": 0,
+                },
+            ),
+            (["int", "int_one"], 1),
+            (["int", "int_minus_one"], -1),
+            (["int", "int_zero"], 0),
+            (
+                ["float"],
+                {
+                    "float_one": 1.0,
+                    "float_minus_one": -1.0,
+                    "float_zero": 0.0,
+                    "float_one_e_nine": 1.0e9,
+                    "float_minus_one_e_minus_nine": -1.0e-9,
+                    "float_nan": math.nan,
+                    "float_inf": math.inf,
+                    "float_minus_inf": -math.inf,
+                },
+            ),
+            (["float", "float_one"], 1.0),
+            (["float", "float_minus_one"], -1.0),
+            (["float", "float_zero"], 0.0),
+            (["float", "float_one_e_nine"], 1.0e9),
+            (["float", "float_minus_one_e_minus_nine"], -1.0e-9),
+            (["float", "float_nan"], math.nan),
+            (["float", "float_inf"], math.inf),
+            (["float", "float_minus_inf"], -math.inf),
+            (
+                ["str"],
+                {
+                    "str_empty": "",
+                    "str": "dummy",
+                },
+            ),
+            (["str", "str_empty"], ""),
+            (["str", "str"], "dummy"),
+            (["list"], [None, True, 1, 1.0, math.nan, math.inf, "dummy"]),
+            (["list", 0], None),
+            (["list", 1], True),
+            (["list", 2], 1),
+            (["list", 3], 1.0),
+            (["list", 4], math.nan),
+            (["list", 5], math.inf),
+            (["list", 6], "dummy"),
+            (["list_list"], [[None], [True], [1], [1.0], [math.nan], [math.inf], ["dummy"]]),
+            (["list_list", 0], [None]),
+            (["list_list", 1], [True]),
+            (["list_list", 2], [1]),
+            (["list_list", 3], [1.0]),
+            (["list_list", 4], [math.nan]),
+            (["list_list", 5], [math.inf]),
+            (["list_list", 6], ["dummy"]),
+            (["list_list", 0, 0], None),
+            (["list_list", 1, 0], True),
+            (["list_list", 2, 0], 1),
+            (["list_list", 3, 0], 1.0),
+            (["list_list", 4, 0], math.nan),
+            (["list_list", 5, 0], math.inf),
+            (["list_list", 6, 0], "dummy"),
+            (
+                ["list_dict"],
+                [{"v": None}, {"v": True}, {"v": 1}, {"v": 1.0}, {"v": math.nan}, {"v": math.inf}, {"v": "dummy"}],
+            ),
+            (["list_dict", 0], {"v": None}),
+            (["list_dict", 1], {"v": True}),
+            (["list_dict", 2], {"v": 1}),
+            (["list_dict", 3], {"v": 1.0}),
+            (["list_dict", 4], {"v": math.nan}),
+            (["list_dict", 5], {"v": math.inf}),
+            (["list_dict", 6], {"v": "dummy"}),
+            (["list_dict", 0, "v"], None),
+            (["list_dict", 1, "v"], True),
+            (["list_dict", 2, "v"], 1),
+            (["list_dict", 3, "v"], 1.0),
+            (["list_dict", 4, "v"], math.nan),
+            (["list_dict", 5, "v"], math.inf),
+            (["list_dict", 6, "v"], "dummy"),
+        ]
+
+        expect = {
+            "none": None,
+            "bool": {
+                "bool_true": True,
+                "bool_false": False,
+            },
+            "int": {
+                "int_one": 1,
+                "int_minus_one": -1,
+                "int_zero": 0,
+            },
+            "float": {
+                "float_one": 1.0,
+                "float_minus_one": -1.0,
+                "float_zero": 0.0,
+                "float_one_e_nine": 1.0e9,
+                "float_minus_one_e_minus_nine": -1.0e-9,
+                "float_nan": math.nan,
+                "float_inf": math.inf,
+                "float_minus_inf": -math.inf,
+            },
+            "str": {
+                "str_empty": "",
+                "str": "dummy",
+            },
+            "list": [None, True, 1, 1.0, math.nan, math.inf, "dummy"],
+            "list_list": [[None], [True], [1], [1.0], [math.nan], [math.inf], ["dummy"]],
+            "list_dict":
+                [{"v": None}, {"v": True}, {"v": 1}, {"v": 1.0}, {"v": math.nan}, {"v": math.inf}, {"v": "dummy"}],
+        }
+
+        for _ in range(1000):
+            obj = {}
+            for _, (node_path, value) in sorted((randomizer().next_float(), query) for query in queries):
+                self.assertTrue(json_set(obj, value, *node_path))
+            self.assertTrue(json_compare(obj, expect))
+
+    def test_json_set__asterisk(self):
+        obj = []
+        for v in range(1000):
+            self.assertTrue(json_set(obj, v, asterisk))
+        self.assertTrue(json_compare(obj, list(range(1000))))
+
     @ddt.data(
         (None, None),
         (True, True),
@@ -73,6 +448,8 @@ class JsonUtilsTest(unittest.TestCase):
         (1, 1),
         (-1, -1),
         (0, 0),
+        (MultipliedInt(-1, 100), -100),
+        (MultipliedInt(1, 100), 100),
         (1.0, 1.0),
         (-1.0, -1.0),
         (0.0, 0.0),
@@ -81,8 +458,6 @@ class JsonUtilsTest(unittest.TestCase):
         (math.nan, math.nan),
         (math.inf, math.inf),
         (-math.inf, -math.inf),
-        (MultipliedInt(-1, 100), -100),
-        (MultipliedInt(1, 100), 100),
         (MultipliedFloat(1.0, 100.0), 100.0),
         (MultipliedFloat(-1.0, 100.0), -100.0),
         ("", ""),
@@ -374,6 +749,8 @@ class JsonUtilsTest(unittest.TestCase):
         (1, 1),
         (-1, -1),
         (0, 0),
+        (MultipliedInt(-1, 100), -100),
+        (MultipliedInt(1, 100), 100),
         (1.0, 1.0),
         (-1.0, -1.0),
         (0.0, 0.0),
@@ -382,8 +759,6 @@ class JsonUtilsTest(unittest.TestCase):
         (math.nan, math.nan),
         (math.inf, math.inf),
         (-math.inf, -math.inf),
-        (MultipliedInt(-1, 100), -100),
-        (MultipliedInt(1, 100), 100),
         (MultipliedFloat(1.0, 100.0), 100.0),
         (MultipliedFloat(-1.0, 100.0), -100.0),
         ("", ""),
@@ -592,6 +967,8 @@ class JsonUtilsTest(unittest.TestCase):
         (1, 1),
         (-1, -1),
         (0, 0),
+        (MultipliedInt(-1, 100), -100),
+        (MultipliedInt(1, 100), 100),
         (1.0, 1.0),
         (-1.0, -1.0),
         (0.0, 0.0),
@@ -600,8 +977,6 @@ class JsonUtilsTest(unittest.TestCase):
         (math.nan, "nan"),
         (math.inf, "inf"),
         (-math.inf, "-inf"),
-        (MultipliedInt(-1, 100), -100),
-        (MultipliedInt(1, 100), 100),
         (MultipliedFloat(1.0, 100.0), 100.0),
         (MultipliedFloat(-1.0, 100.0), -100.0),
         ("", ""),
