@@ -4,8 +4,8 @@ import ddt
 
 from iker.common.utils.dtutils import dt_utc
 from iker.common.utils.strutils import is_blank, is_empty, is_none
+from iker.common.utils.strutils import make_params_string, parse_params_string
 from iker.common.utils.strutils import parse_bool, parse_float_or, parse_int_or
-from iker.common.utils.strutils import parse_params_string
 from iker.common.utils.strutils import str_conv
 from iker.common.utils.strutils import strip_margin
 from iker.common.utils.strutils import trim_to_empty, trim_to_none
@@ -204,14 +204,20 @@ class StrUtilsTest(unittest.TestCase):
     @ddt.data(
         ("", {}),
         (" \t", {}),
+        (",-,", {}),
         ("foo=bar", {"foo": "bar"}),
         (
             "dummy_key_1=dummy_value_1,dummy_key_2=dummy_value_2",
             {"dummy_key_1": "dummy_value_1", "dummy_key_2": "dummy_value_2"},
         ),
         (
-            "dummy_key_1=dummy_value_1,dummy_key_2=dummy_value_2,dummy_key_3",
-            {"dummy_key_1": "dummy_value_1", "dummy_key_2": "dummy_value_2", "dummy_key_3": "True"},
+            "dummy_key_1=dummy_value_1,dummy_key_2=dummy_value_2,dummy_key_3,-dummy_key_4",
+            {
+                "dummy_key_1": "dummy_value_1",
+                "dummy_key_2": "dummy_value_2",
+                "dummy_key_3": True,
+                "dummy_key_4": False,
+            },
         ),
         (
             "dummy_key_1=dummy_value_1,dummy_key_2=dummy_value_2,dummy_key_3=do not use spaces in strings CLI",
@@ -230,8 +236,42 @@ class StrUtilsTest(unittest.TestCase):
         ),
     )
     @ddt.unpack
-    def test_parse_params_string(self, s, params_dict):
-        self.assertDictEqual(params_dict, parse_params_string(s))
+    def test_parse_params_string(self, data, expect):
+        self.assertDictEqual(expect, parse_params_string(data))
+        self.assertDictEqual(expect, parse_params_string(make_params_string(parse_params_string(data))))
+
+    @ddt.data(
+        (None, ""),
+        ({}, ""),
+        ({"foo": "bar"}, "foo=bar"),
+        (
+            {"dummy_key_1": "dummy_value_1", "dummy_key_2": "dummy_value_2"},
+            "dummy_key_1=dummy_value_1,dummy_key_2=dummy_value_2",
+        ),
+        (
+            {"dummy_key_1": "dummy_value_1", "dummy_key_2": "dummy_value_2", "dummy_key_3": True, "dummy_key_4": False},
+            "dummy_key_1=dummy_value_1,dummy_key_2=dummy_value_2,dummy_key_3,-dummy_key_4",
+        ),
+        (
+            {
+                "dummy_key_1": "dummy_value_1",
+                "dummy_key_2": "dummy_value_2",
+                "dummy_key_3": "do not use spaces in strings CLI",
+            },
+            "dummy_key_1=dummy_value_1,dummy_key_2=dummy_value_2,dummy_key_3=do not use spaces in strings CLI",
+        ),
+        (
+            {
+                "dummy_key_1": "dummy_value_1_key=dummy_value_1_value",
+                "dummy_key_2": "dummy_value_2_key=dummy_value_2_value",
+            },
+            "dummy_key_1=dummy_value_1_key=dummy_value_1_value,dummy_key_2=dummy_value_2_key=dummy_value_2_value",
+        ),
+    )
+    @ddt.unpack
+    def test_make_params_string(self, data, expect):
+        self.assertEqual(expect, make_params_string(data))
+        self.assertEqual(expect, make_params_string(parse_params_string(make_params_string(data))))
 
     @ddt.data(
         (
@@ -394,7 +434,33 @@ class StrUtilsTest(unittest.TestCase):
                 "Donec et erat vel mi dapibus lobortis. Suspendisse in fringilla nunc. Fusce venenatis, ex nec aliquam faucibus, dolor mi dignissim nulla, vel dictum massa dolor vitae purus. Ut ullamcorper arcu non nulla eleifend malesuada. Curabitur massa est, volutpat ornare pulvinar ut, elementum in felis. Interdum et malesuada fames ac ante ipsum primis in faucibus. Integer magna erat, ullamcorper eget tristique eu, interdum vitae nulla. Nulla facilisi.",
             ]
         ),
+        (
+            """
+            中天山果水灵方宫林道理星飞鸟腾云下山，奇梦海园恬意鸟鸣群风神奇岁月。
+            绿水青山画笔天际风景苍松古道日月行空。
+            树影斜阳天高地阔，烟雾缭绕草原湖泊动情。
+            年华似水时间错落，云卷云舒风起时长。
+            """,
+            [
+                "中天山果水灵方宫林道理星飞鸟腾云下山，奇梦海园恬意鸟鸣群风神奇岁月。绿水青山画笔天际风景苍松古道日月行空。树影斜阳天高地阔，烟雾缭绕草原湖泊动情。年华似水时间错落，云卷云舒风起时长。",
+                "",
+            ],
+            ""
+        ),
+        (
+            """
+            |中天山果水灵方宫林道理星飞鸟腾云下山，奇梦海园恬意鸟鸣群风神奇岁月。
+            |绿水青山画笔天际风景苍松古道日月行空。
+            |树影斜阳天高地阔，烟雾缭绕草原湖泊动情。
+            |年华似水时间错落，云卷云舒风起时长。
+            """,
+            [
+                "中天山果水灵方宫林道理星飞鸟腾云下山，奇梦海园恬意鸟鸣群风神奇岁月。绿水青山画笔天际风景苍松古道日月行空。树影斜阳天高地阔，烟雾缭绕草原湖泊动情。年华似水时间错落，云卷云舒风起时长。",
+                "",
+            ],
+            ""
+        ),
     )
     @ddt.unpack
-    def test_strip_margin(self, data, expect):
-        self.assertEqual(strip_margin(data), "\n".join(expect))
+    def test_strip_margin(self, data, expect, line_concat: str = " "):
+        self.assertEqual(strip_margin(data, line_concat=line_concat), "\n".join(expect))
